# MetaSBT

MetaSBT is a scalable framework designed to automatically index microbial genomes and accurately characterize metagenome-assembled genomes using Sequence Bloom Trees.

👉 Get started with MetaSBT by visiting our [official wiki](https://github.com/cumbof/MetaSBT/wiki).

We also maintain a collection of public databases built with MetaSBT from curated sets of microbial genomes. You can explore and use them from the [MetaSBT-DBs](https://github.com/cumbof/MetaSBT-DBs) repository.

> [!NOTE]
> Interested in using MetaSBT or our databases, or building your own private database but lack the necessary computational resources?
> Reach out to us! We’re always open to collaborations.

## 📖 Credits

If you use MetaSBT in your work, please cite:

> _Manuscript in preparation_

## 🤝 Contributing

Long-term discussion and bug reports are maintained via GitHub [Discussions](https://github.com/cumbof/MetaSBT/discussions) and [Issues](https://github.com/cumbof/MetaSBT/issues), while code review is managed via GitHub [Pull Requests](https://github.com/cumbof/MetaSBT/pulls).

Before contributing, please:
1. Check for existing issues or PRs related to your topic;
2. Write clear and concise titles and descriptions;
3. Include steps to reproduce bugs, relevant logs, version info, and other technical details when appropriate.

## 🛠️ Support

Need help?

Open an [Issue](https://github.com/cumbof/MetaSBT/issues) or start a [Discussion](https://github.com/cumbof/MetaSBT/discussions) — we're happy to assist with any questions or technical problems.

Copyright © 2025 [Fabio Cumbo](https://github.com/cumbof), [Daniel Blankenberg](https://github.com/blankenberg). See [LICENSE](https://github.com/cumbof/MetaSBT/blob/main/LICENSE) for additional details.
